@@ -217,8 +217,8 @@ gchar*
 exo_strdup_strftime (const gchar     *format,
                      const struct tm *tm)
 {
-  static const gchar C_STANDARD_STRFTIME_CHARACTERS[] = "aAbBcdHIjmMpSUwWxXyYZ";
-  static const gchar C_STANDARD_NUMERIC_STRFTIME_CHARACTERS[] = "dHIjmMSUwWyY";
+  static const gchar C_STANDARD_STRFTIME_CHARACTERS[] = "aAbBcCdeFgGhHIjklmMnprRsStTuUVwWxXyYzZ";
+  static const gchar C_STANDARD_NUMERIC_STRFTIME_CHARACTERS[] = "CdegGHIjklmMsSuUVwWyY";
   static const gchar SUS_EXTENDED_STRFTIME_MODIFIERS[] = "EO";
   const gchar       *remainder;
   const gchar       *percent;
@@ -231,7 +231,7 @@ exo_strdup_strftime (const gchar     *format,
   gchar             *piece;
   gchar             *result;
   gchar             *converted;
-  gchar              modifier;
+  gchar              modifier = 0;
   gint               i;
 
   /* Format could be translated, and contain UTF-8 chars,
@@ -292,7 +292,6 @@ exo_strdup_strftime (const gchar     *format,
           break;
         }
 
-      modifier = 0;
       if (strchr (SUS_EXTENDED_STRFTIME_MODIFIERS, *remainder) != NULL)
         {
           modifier = *remainder++;
